@@ -57,6 +57,7 @@ typedef struct {
 
   gboolean is_primary;
   gboolean is_presentation;
+  gboolean is_underscanning;
 } MetaOutputConfig;
 
 typedef struct {
@@ -112,7 +113,8 @@ struct _FlashbackMonitorConfig
   gboolean                 current_is_for_laptop_lid;
   MetaConfiguration       *previous;
 
-  GFile                   *file;
+  GFile                   *user_file;
+  GFile                   *system_file;
   GCancellable            *save_cancellable;
 
   UpClient                *up_client;
@@ -663,6 +665,7 @@ meta_monitor_config_assign_crtcs (MetaConfiguration       *config,
                                                 &config->keys[i]);
       output_info->is_primary = output_config->is_primary;
       output_info->is_presentation = output_config->is_presentation;
+      output_info->is_underscanning = output_config->is_underscanning;
 
       g_ptr_array_add (outputs, output_info);
     }
@@ -864,7 +867,8 @@ handle_start_element (GMarkupParseContext  *context,
              strcmp (element_name, "reflect_x") == 0 ||
              strcmp (element_name, "reflect_y") == 0 ||
              strcmp (element_name, "primary") == 0 ||
-             strcmp (element_name, "presentation") == 0) && parser->unknown_count == 0)
+             strcmp (element_name, "presentation") == 0 ||
+             strcmp (element_name, "underscanning") == 0) && parser->unknown_count == 0)
           {
             parser->state = STATE_OUTPUT_FIELD;
 
@@ -1171,6 +1175,8 @@ handle_text (GMarkupParseContext *context,
           parser->output.is_primary = read_bool (text, text_len, error);
         else if (strcmp (parser->output_field, "presentation") == 0)
           parser->output.is_presentation = read_bool (text, text_len, error);
+        else if (strcmp (parser->output_field, "underscanning") == 0)
+          parser->output.is_underscanning = read_bool (text, text_len, error);
         else
           g_assert_not_reached ();
         return;
@@ -1188,8 +1194,9 @@ static const GMarkupParser config_parser = {
   .text = handle_text,
 };
 
-static void
-flashback_monitor_config_load (FlashbackMonitorConfig *self)
+static gboolean
+load_config_file (FlashbackMonitorConfig *self,
+                  GFile                  *file)
 {
   char *contents;
   gsize size;
@@ -1207,14 +1214,11 @@ flashback_monitor_config_load (FlashbackMonitorConfig *self)
   */
 
   error = NULL;
-  ok = g_file_load_contents (self->file, NULL, &contents, &size, NULL, &error);
+  ok = g_file_load_contents (file, NULL, &contents, &size, NULL, &error);
   if (!ok)
     {
-      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
-        g_warning ("Failed to load stored monitor configuration: %s\n", error->message);
-
       g_error_free (error);
-      return;
+      return FALSE;
     }
 
   memset (&parser, 0, sizeof (ConfigParser));
@@ -1243,6 +1247,17 @@ flashback_monitor_config_load (FlashbackMonitorConfig *self)
 
   g_markup_parse_context_free (context);
   g_free (contents);
+
+  return ok;
+}
+
+static void
+flashback_monitor_config_load (FlashbackMonitorConfig *self)
+{
+  if (self->user_file && load_config_file (self, self->user_file))
+    return;
+  if (self->system_file && load_config_file (self, self->system_file))
+    return;
 }
 
 static unsigned long
@@ -1644,6 +1659,7 @@ init_config_from_output (MetaOutputConfig *config,
   config->transform = output->crtc->transform;
   config->is_primary = output->is_primary;
   config->is_presentation = output->is_presentation;
+  config->is_underscanning = output->is_underscanning;
 }
 
 static void
@@ -1738,7 +1754,8 @@ meta_monitor_config_save (FlashbackMonitorConfig *self)
                                       "      <reflect_x>%s</reflect_x>\n"
                                       "      <reflect_y>no</reflect_y>\n"
                                       "      <primary>%s</primary>\n"
-                                      "      <presentation>%s</presentation>\n",
+                                      "      <presentation>%s</presentation>\n"
+                                      "      <underscanning>%s</underscanning>\n",
                                       output->rect.width,
                                       output->rect.height,
                                       refresh_rate,
@@ -1747,7 +1764,8 @@ meta_monitor_config_save (FlashbackMonitorConfig *self)
                                       rotation_map[output->transform & 0x3],
                                       output->transform >= META_MONITOR_TRANSFORM_FLIPPED ? "yes" : "no",
                                       output->is_primary ? "yes" : "no",
-                                      output->is_presentation ? "yes" : "no");
+                                      output->is_presentation ? "yes" : "no",
+                                      output->is_underscanning ? "yes" : "no");
             }
 
           g_string_append (buffer, "    </output>\n");
@@ -1762,7 +1780,7 @@ meta_monitor_config_save (FlashbackMonitorConfig *self)
   closure->config = g_object_ref (self);
   closure->buffer = buffer;
 
-  g_file_replace_contents_async (self->file,
+  g_file_replace_contents_async (self->user_file,
                                  buffer->str, buffer->len,
                                  NULL, /* etag */
                                  TRUE,
@@ -1798,6 +1816,7 @@ flashback_monitor_config_init (FlashbackMonitorConfig *config)
 {
   const char *filename;
   char *path;
+  const char * const *system_dirs;
 
   config->configs = g_hash_table_new_full (config_hash, config_equal,
                                            NULL, (GDestroyNotify) config_unref);
@@ -1807,9 +1826,17 @@ flashback_monitor_config_init (FlashbackMonitorConfig *config)
     filename = "monitors.xml";
 
   path = g_build_filename (g_get_user_config_dir (), filename, NULL);
-  config->file = g_file_new_for_path (path);
+  config->user_file = g_file_new_for_path (path);
   g_free (path);
 
+  for (system_dirs = g_get_system_config_dirs (); !config->system_file && *system_dirs; system_dirs++)
+    {
+      path = g_build_filename (*system_dirs, filename, NULL);
+      if (g_file_test (path, G_FILE_TEST_EXISTS))
+        config->system_file = g_file_new_for_path (path);
+      g_free (path);
+    }
+
   config->up_client = up_client_new ();
   config->lid_is_closed = up_client_get_lid_is_closed (config->up_client);
 
